%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 2, Column 4                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Joint Maximization of pi and f.

clear; clc;
C     = 100;  % number of clusters
n     = 10;   % cluster size
alpha = 0.05; % significance
gamma = 0.8;  % power
tau   = 0.1;  % variance of cluster error (tau^2)
sigma = 0.9;  % variance of individual error (sigma^2)

x     = [0.01:.03:.99]; % values for optimization
obj_star=Inf; MDE_T_opt=Inf; MDE_S_opt=Inf; MDSE_T_opt=Inf; MDSE_S_opt=Inf;

for k = 1:length(x)-1;
    for m = k + 1:length(x);
        pi = [0,x(k),x(m)];     
        MDE_T = ones(length(x),length(x));
        MDE_S = MDE_T; MDSE_T = MDE_T; MDSE_S = MDE_T;

        for i = 1:length(x);
            l = length(x)-i;
            for j = 1:l;
                f = [x(i),x(j),1-x(i)-x(j)]; 
                [MDE_T(i,j), MDE_S(i,j),z] = power_pooled2(n,C,alpha,gamma,tau,sigma,pi,f);
                [MDSE_T(i,j),z] = power_slope2(n,C,alpha,gamma,tau,sigma,pi,f,2,3);
                [z,MDSE_S(i,j)] = power_slope2(n,C,alpha,gamma,tau,sigma,pi,f,1,3);
            end;
        end;
        
        obj   = MDE_T + MDE_S + MDSE_T + MDSE_S; % objective function
        [i,j] = index_min(obj); % index of x that minimizes obj
        temp  = MDE_T(i,j) + MDE_S(i,j) + MDSE_T(i,j) + MDSE_S(i,j);

        if obj_star > temp;
            obj_star = temp;
            psi = x(i); % optimal f(0)
            f_1 = x(j); % optimal f(pi_1)
            pi1 = x(k); % optimal pi_1
            pi2 = x(m); % optimal pi_2
            MDE_T_opt  = MDE_T(i,j);  % MDE_T at optimal values
            MDE_S_opt  = MDE_S(i,j);  % MDE_S at optimal values
            MDSE_T_opt = MDSE_T(i,j); % MDSE_T at optimal values
            MDSE_S_opt = MDSE_S(i,j); % MDSE_S at optimal values
        end;
    end;
    k
end;

[psi, f_1, pi1, pi2, MDE_T_opt, MDE_S_opt, MDSE_T_opt, MDSE_S_opt, obj_star]

