
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                 %
%      Replication Code for Baird et al. 2016     %
%                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 1, Column 1                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Clustered design
% Half of clusters pure control, half pure treatment, ICC = 0.0

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0;         % variance of cluster error (tau^2)
sigma = 1;         % variance of individual error (sigma^2)
pi    = [0,1];     % cluster saturations
f     = [1/2,1/2]; % fraction of clusters in each saturation, respectively

[MDE_T, MDE_S, MDE_Tonly] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
MDE_Tonly


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 1, Column 2                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Clustered design
% Half of clusters pure control, half pure treatment, ICC = 0.1

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0.1;       % variance of cluster error (tau^2)
sigma = 0.9;       % variance of individual error (sigma^2)
pi    = [0,1];     % cluster saturations
f     = [1/2,1/2]; % fraction of clusters in each saturation, respectively

[MDE_T, MDE_S, MDE_Tonly] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
MDE_Tonly


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 1, Column 3                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Clustered design
% Half of clusters pure control, half pure treatment, ICC = 1.0

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 1;         % variance of cluster error    (tau^2)
sigma = 0;         % variance of individual error (sigma^2)
pi    = [0,1];     % cluster saturations
f     = [1/2,1/2]; % fraction of clusters in each saturation, respectively

[MDE_T, MDE_S, MDE_Tonly] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
MDE_Tonly


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 1, Column 4                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Partial Population design
% Half of clusters pure control, half partially treated, ICC = 0.0

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0;         % variance of cluster error (tau^2)
sigma = 1;         % variance of individual error (sigma^2)
pi    = [0,0.5];   % cluster saturations
psi   = [0.01:.001:.99];
MDE_T = zeros(1,length(psi));
MDE_S = MDE_T;

for j = 1:length(psi);
    f = [psi(j),1-psi(j)]; 
    [MDE_T(j), MDE_S(j),z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
end;

obj   = MDE_T + MDE_S;  % objective function to maximize
[i,j] = index_min(obj); % index of psi that minimizes objective
psi(i,j)                % optimal proportion of pure control clusters
1 - psi(i,j)            % optimal proportion of partial treatment clusters
MDE_T(i,j)              % MDE_T at optimal control size
MDE_S(i,j)              % MDE_S at optimal control size


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 1, Column 5                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Partial Population design
% Half of clusters pure control, half partially treated, ICC = 0.1

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0.1;       % variance of cluster error (tau^2)
sigma = 0.9;       % variance of individual error (sigma^2)
pi    = [0,0.5];   % cluster saturations
psi   = [0.01:.001:.99];
MDE_T = zeros(1,length(psi));
MDE_S = MDE_T;

for j = 1:length(psi);%j=500
    f = [psi(j),1-psi(j)]; 
    [MDE_T(j), MDE_S(j),z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
end;

obj   = MDE_T + MDE_S;  % objective function to maximize
[i,j] = index_min(obj); % index of psi that minimizes objective
psi(i,j)                % optimal proportion of pure control clusters
1 - psi(i,j)            % optimal proportion of partial treatment clusters
MDE_T(i,j)              % MDE_T at optimal control size
MDE_S(i,j)              % MDE_S at optimal control size


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 1, Column 6                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Partial Population design
% Half of clusters pure control, half partially treated, ICC = 1.0

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 1;         % variance of cluster error (tau^2)
sigma = 0;         % variance of individual error (sigma^2)
pi    = [0,0.5];   % cluster saturations
psi   = [0.01:.001:.99];
MDE_T = zeros(1,length(psi)); 
MDE_S = MDE_T;

for j = 1:length(psi);
    f = [psi(j),1-psi(j)]; 
    [MDE_T(j), MDE_S(j),z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
end;

obj   = MDE_T+MDE_S;    % objective function to maximize
[i,j] = index_min(obj); % index of psi that minimizes objective
psi(i,j)                % optimal proportion of pure control clusters
1-psi(i,j)              % optimal proportion of partial treatment clusters
MDE_T(i,j)              % MDE_T at optimal control size
MDE_S(i,j)              % MDE_S at optimal control size % Begin Table 1, Column 6


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 1, Column 7-8              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Table 2, Column 7
% Partial Population design
% Some clusters pure control, the rest partially treated, ICC = 0.1
% Subject to twice as much weight on MDE_S compared to MDE_T

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0.1;       % variance of cluster error (tau^2)
sigma = 0.9;       % variance of individual error (sigma^2)
x     = [0.01:.005:.99]; % values for optimization
MDE_T = zeros(length(x),length(x)); 
MDE_S = MDE_T;

for i = 1:length(x);
    pi = [0,x(i)];
    for j = 1:length(x);
        f = [x(j),1-x(j)]; 
        [MDE_T(i,j), MDE_S(i,j),z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
    end;
end;

obj   = MDE_T + 2*MDE_S;% objective function to maximize
[i,j] = index_min(obj); % index of psi that minimizes MDE_T
x(i)                    % optimal saturation of treatment
x(j)                    % optimal proportion of pure control clusters
1-x(j)                  % optimal proportion of partial treatment clusters
MDE_T(i,j)              % MDE_T at optimal control size
MDE_S(i,j)              % MDE_S at optimal control size

%%%% Table 2, Column 8
% Partial Population design
% Some clusters pure control, the rest partially treated, ICC = 0.1
% Subject to MDE_T <= 0.25

MDE_S_aug = MDE_S;
for i = 1:length(x);
    for j = 1:length(x);
        if MDE_T(i,j) > 0.25;
            MDE_S_aug(i,j) = Inf;
        end;
    end;
end;
obj = MDE_S_aug;        % objective function to maximize
[i,j] = index_min(obj); % index of psi that minimizes MDE_S
x(i)                    % optimal saturation of treatment
x(j)                    % optimal proportion of pure control clusters
1 - x(j)                % optimal proportion of partial treatment clusters
MDE_T(i,j)              % MDE_T at optimal control size
MDE_S(i,j)              % MDE_S at optimal control size


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 2, Column 1                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Random saturation design (two partially treated clusters), ICC = 0.0
% Optimal cluster saturations and allocation

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau    = 0.0;      % variance of cluster error (tau^2)
sigma  = 1.0;      % variance of individual error (sigma^2)
x      = [0.01:.01:.5]; % values for optimization
MDSE_T = zeros(length(x),length(x));
MDSE_S = MDSE_T;

for i = 1:length(x);
    pi = [x(i),1-x(i)];
    for j = 1:length(x);
        f = [x(j),1-x(j)];
        [MDSE_T(i,j),MDSE_S(i,j)] = power_slope(n,C,alpha,gamma,tau,sigma,pi,f,1,2);
    end;
end;

obj   = MDSE_T + MDSE_S; % objective function to maximize
[i,j] = index_min(obj); % index of psi that minimizes objective
x(i)         % optimal saturation for lower saturation
1 - x(i)     % optimal saturation for higher saturation
x(j)         % optimal fraction of clusters in lower saturation
1 - x(j)     % optimal fraction of clusters in higher saturation
MDSE_T(i,j)  % MDSE_T at optimal 
MDSE_S(i,j)  % MDSE_S at optimal


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 2, Column 2                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Random saturation design (two partially treated clusters), ICC = 0.1
% Optimal cluster saturations and allocation

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau    = 0.1;      % variance of cluster error (tau^2)
sigma  = 0.9;      % variance of individual error (sigma^2)
x      = [0.01:.01:.5]; % values for optimization
MDSE_T = zeros(length(x),length(x));
MDSE_S = MDSE_T;

for i = 1:length(x);
    pi = [x(i),1-x(i)];
    for j = 1:length(x);
        f = [x(j),1-x(j)];
        [MDSE_T(i,j),MDSE_S(i,j)] = power_slope(n,C,alpha,gamma,tau,sigma,pi,f,1,2);
    end;
end;

obj   = MDSE_T + MDSE_S; % objective function to maximize
[i,j] = index_min(obj); % index of psi that minimizes objective
x(i)         % optimal saturation for lower saturation
1 - x(i)     % optimal saturation for higher saturation
x(j)         % optimal fraction of clusters in lower saturation
1 - x(j)     % optimal fraction of clusters in higher saturation
MDSE_T(i,j)  % MDSE_T at optimal 
MDSE_S(i,j)  % MDSE_S at optimal


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 2, Column 3                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Random saturation design (two partially treated clusters), ICC = 1.0
% Optimal cluster saturations and allocation

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau    = 1.0;      % variance of cluster error (tau^2)
sigma  = 0.0;      % variance of individual error (sigma^2)
x      = [0.01:.01:.5]; % values for optimization
MDSE_T = zeros(length(x),length(x));
MDSE_S = MDSE_T;

for i = 1:length(x);
    pi = [x(i),1-x(i)];
    for j = 1:length(x);
        f = [x(j),1-x(j)];
        [MDSE_T(i,j),MDSE_S(i,j)] = power_slope(n,C,alpha,gamma,tau,sigma,pi,f,1,2);
    end;
end;

obj   = MDSE_T + MDSE_S; % objective function to maximize
[i,j] = index_min(obj); % index of psi that minimizes objective
x(i)         % optimal saturation for lower saturation
1 - x(i)     % optimal saturation for higher saturation
x(j)         % optimal fraction of clusters in lower saturation
1 - x(j)     % optimal fraction of clusters in higher saturation
MDSE_T(i,j)  % MDSE_T at optimal 
MDSE_S(i,j)  % MDSE_S at optimal


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 2, Column 4                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Joint maximization across MDE and MDSE.
% NOTE: pi has been maximized using the a joint maximization process,
% performed in Complete_Maximization.m.

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0.1;       % variance of cluster error (tau^2)
sigma = 0.9;       % variance of individual error (sigma^2)
pi=[0,0.21,0.88];  % cluster saturations.
x=[0.01:.01:.99];  % values for maximization.

MDE_T=ones(length(x),length(x));MDE_S=MDE_T;MDSE_T=MDE_T;MDSE_S=MDE_T;

for i=1:length(x);
    l=length(x)-i;
    for j=1:l;
        f=[x(i),x(j),1-x(i)-x(j)]; 
        [MDE_T(i,j), MDE_S(i,j),z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
        [MDSE_T(i,j),z] = power_slope(n,C,alpha,gamma,tau,sigma,pi,f,2,3);
        [z,MDSE_S(i,j)] = power_slope(n,C,alpha,gamma,tau,sigma,pi,f,1,3);
    end;
end;

obj = MDE_T+MDE_S+MDSE_T+MDSE_S; % objective function to maximize
[i,j] = index_min(obj);          % indices of x that minimizes objective function
[x(i), x(j), 1-x(i)-x(j)]        % optimal f
[MDE_T(i,j),MDE_S(i,j),MDSE_T(i,j),MDSE_S(i,j)] % optimal MDEs/MDSEs.
%Returns MDSE_T between saturations 0.21 and 0.88
%Returns MDSE_S between saturations 0 and 0.88


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 2, Column 5                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MDEs resulting from study design of Banerjee et al.

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0.1;       % variance of cluster error (tau^2)
sigma = 0.9;       % variance of individual error (sigma^2)
pi    = [0,0.25,0.5,0.75,1];   % cluster saturations
f     = [0.2,0.2,0.2,0.2,0.2]; % fraction of clusters in each saturation
MDE_T = 0;MDE_S = 0;MDE_Tonly = 0;MDSE_T = 0;MDSE_S = 0;

[MDE_T,MDE_S,z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
[MDSE_T,z]      = power_slope (n,C,alpha,gamma,tau,sigma,pi,f,2,5); 
[z,MDSE_S]      = power_slope (n,C,alpha,gamma,tau,sigma,pi,f,1,4); 
[MDE_T,MDE_S,MDSE_T,MDSE_S]
%Returns MDSE_T between saturations 0.25 and 1
%Returns MDSE_S between saturations 0 and .75

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 2, Column 6                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MDEs resulting from study design of Sinclair et al.

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0.1;       % variance of cluster error (tau^2) 
sigma = 0.9;       % variance of individual error (sigma^2)
pi    = [0,0.1,0.5,1];         % cluster saturations
f     = [0.25,0.25,0.25,0.25]; % fraction of clusters in each saturation
MDE_T = 0; MDE_S = 0; MDE_Tonly = 0; MDSE_T = 0; MDSE_S = 0;

[MDE_T,MDE_S,z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
[MDSE_T,z]      = power_slope (n,C,alpha,gamma,tau,sigma,pi,f,2,4);
[z,MDSE_S]      = power_slope (n,C,alpha,gamma,tau,sigma,pi,f,1,3);
[MDE_T,MDE_S,MDSE_T,MDSE_S]
%Returns MDSE_T between saturations 0.1 and 1
%Returns MDSE_S between saturations 0 and .5

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                Table 2, Column 7-8              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Table 2, Column 7
% MDEs resulting from study design of Baird et al.

clear; clc;
n     = 10;        % cluster size
C     = 100;       % number of clusters
alpha = 0.05;      % significance
gamma = 0.8;       % power
tau   = 0.1;       % variance of cluster error (tau^2)
sigma = 0.9;       % variance of individual error (sigma^2)
pi    = [0,0.33,0.67,1];       % cluster saturations
f     = [0.55,0.15,0.15,0.15]; % fraction of clusters in each saturation
MDE_T = 0; MDE_S = 0; MDE_Tonly = 0; MDSE_T = 0; MDSE_S = 0;

[MDE_T,MDE_S,z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
[MDSE_T,z]      = power_slope (n,C,alpha,gamma,tau,sigma,pi,f,2,4);
[z,MDSE_S]      = power_slope (n,C,alpha,gamma,tau,sigma,pi,f,1,3);
[MDE_T,MDE_S,MDSE_T,MDSE_S]
%Returns MDSE_T between saturations 0.33 and 1
%Returns MDSE_S between saturations 0 and .67

%%%% Table 2, Column 8
% Design to minimize MDE_S subject to:
% 1.)  MDE_T held no larger than that of Baird et al. (MDE_T <= 0.2679)
% 2.)  Saturation bins pi held the same as Baird et al.
% 3.)  The share of clusters in interior saturations held equal: f(1/3)=f(2/3)

x     = [0.01:.01:.99]; % values for optimization
MDE_T = ones(length(x),length(x));MDE_S = MDE_T; MDSE_T = MDE_T; MDSE_S = MDE_T;

for i = 1:length(x);
    l = length(x)-i;
    for j = 1:l;
        f = [x(i),(1-x(i)-x(j))/2,(1-x(i)-x(j))/2, x(j)]; 
        [MDE_T(i,j), MDE_S(i,j),z] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f);
        [MDSE_T(i,j),z] = power_slope (n,C,alpha,gamma,tau,sigma,pi,f,2,4);
        [z,MDSE_S(i,j)] = power_slope (n,C,alpha,gamma,tau,sigma,pi,f,1,3);
    end;
end;

MDE_S_aug  = MDE_S;
for i = 1:length(x);
    for j = 1:length(x);
        if MDE_T(i,j) > 0.2679;
            MDE_S_aug(i,j) = Inf;
        end;
    end;
end;
obj   = MDE_S_aug;      % objective function to maximize
[i,j] = index_min(obj); % index of x that minimizes MDE_S
x(i)            % optimal fraction of clusters in pure control
(1-x(i)-x(j))/2 % optimal fraction of clusters in two middle saturations
x(j)            % optimal fraction of clusters in pure treatment
MDE_T(i,j)      % MDE_T  at optimal control size
MDE_S(i,j)      % MDE_S  at optimal control size
MDSE_T(i,j)     % MDSE_T at optimal control size
MDSE_S(i,j)     % MDSE_S at optimal control size
