function [MDE_T1,MDE_T2,MDE_S1,MDE_S2] = power_ind(n,C,alpha,gamma,tau,sigma,pi,f)

    %Critical t-values
    t_alpha = tinv(1 - alpha/2,n*C-3); % critical value for Type I  error
    t_gamma = tinv(gamma,n*C-3);       % critical value for Type II error

    % Initialize distribution statistics
    mu_ind  = zeros(1,length(pi));
    p_ind   = zeros(1,length(pi));

    % Calculate distribution statistics
    for i = 1:length(pi);
        mu_ind(i)  = pi(i) * f(i);
        p_ind(i)   = (1-pi(i)) * f(i);
    end;

    psi  = 0; if pi(1) == 0; psi = f(1); end;
    
    % Variance multipliers
    varN  = tau + sigma;
    varCo = (n-1)*tau;
    varC  = n*tau + sigma;

    %%%%%%%%%%%% Minimum Detectable Effects %%%%%%%%%%%%
    MDE_T1 = (t_alpha+t_gamma)*(1/(n*C)*(varCo*(1/f(1)+1/psi)+varN*(1/mu_ind(1)+1/psi))).^0.5;
    MDE_S1 = (t_alpha+t_gamma)*(1/(n*C)*(varCo*(1/f(1)+1/psi)+varN*(1/p_ind(1) +1/psi))).^0.5;
    MDE_T2 = (t_alpha+t_gamma)*(1/(n*C)*(varCo*(1/f(2)+1/psi)+varN*(1/mu_ind(2)+1/psi))).^0.5;
    MDE_S2 = (t_alpha+t_gamma)*(1/(n*C)*(varCo*(1/f(2)+1/psi)+varN*(1/p_ind(2) +1/psi))).^0.5;

end
