function [MDE_T, MDE_S,MDE_Tonly] = power_pooled(n,C,alpha,gamma,tau,sigma,pi,f)
 
    % Critical t-values
    t_alpha = tinv(1 - alpha/2,n*C-3); % critical value for Type I  error
    t_gamma = tinv(gamma,n*C-3);       % critical value for Type II error
    
    % Initialize distribution statistics
    mu_ind  = zeros(1,length(pi));
    eta_ind = zeros(1,length(pi));

    % Calculate distribution statistics
    for i = 1:length(pi);
        mu_ind(i)  = pi(i) * f(i);
        eta_ind(i) = pi(i)^2 * f(i);
    end;

    mu   = sum(mu_ind);
    eta  = sum(eta_ind); % eta=E[pi^2] here; eta=eta-mu^2 in the paper.
    psi  = 0;if pi(1) == 0; psi = f(1); end;
    muS  = 1 - mu - psi;
    etaT = (eta-mu^2)/(1-psi)-(psi/(1-psi)^2)*mu^2;
    
    % Variance multipliers
    varN  = tau + sigma;
    varCo = (n-1) * tau;
    
    %%%%%%%%% Minimum Detectable Effects %%%%%%%%%
    % In the case of a non-trivial design
    Var_T = 1/(n*C)*(varCo*(1/(psi*(1-psi)) + (1-psi)/(mu ^2)*etaT) + varN*(psi+mu )/(mu *psi));
    Var_S = 1/(n*C)*(varCo*(1/(psi*(1-psi)) + (1-psi)/(muS^2)*etaT) + varN*(psi+muS)/(muS*psi));
    MDE_T = (t_alpha + t_gamma)*Var_T^0.5;
    MDE_S = (t_alpha + t_gamma)*Var_S^0.5;
      
    % In the case of using with-in cluster controls as pure controls
    Var_T = 1/(n*C)*(varCo*(eta-mu^2)/(mu^2*(1-mu)^2) + varN/(mu*(1-mu)));
    MDE_Tonly = (t_alpha+t_gamma)*Var_T^0.5;
    
end


